dtdElementValidEntry: Determines whether an XML element allows a particular type of...

View source: R/DTD.R

dtdElementValidEntryR Documentation

Determines whether an XML element allows a particular type of sub-element.

Description

This tests whether name is a legitimate tag to use as a direct sub-element of the element tag according to the definition of the element element in the specified DTD. This is a generic function that dispatches on the element type, so that different version take effect for XMLSequenceContent, XMLOrContent, XMLElementContent.

Since parseDTD no longer works, this function isn't expected to work either and will be removed in a future version of XML.

Usage

dtdElementValidEntry(element, name, pos=NULL)

Arguments

element

The XMLElementDef defining the tag in which we are asking whether the sub-element can be used.

name

The name of the sub-element about which we are querying the list of sub-tags within element.

pos

An optional argument which, if supplied, queries whether the name sub-element is valid as the pos-th child of element.

Details

This is not intended to be called directly, but indirectly by the dtdValidElement function.

Value

Logical value indicating whether the sub-element can appear in an element tag or not.

Author(s)

Duncan Temple Lang

References

https://www.w3.org/XML/, http://www.jclark.com/xml/, https://www.omegahat.net

See Also

parseDTD, dtdValidElement, dtdElement

Examples

 dtdFile <- system.file("exampleData", "foo.dtd",package="XML")
 dtd <- parseDTD(dtdFile) 
 

XML documentation built on March 20, 2026, 9:06 a.m.