dtdIsAttribute: Query if a name is a valid attribute of a DTD element.

View source: R/DTD.R

dtdIsAttributeR Documentation

Query if a name is a valid attribute of a DTD element.

Description

Examines the definition of the DTD element definition identified by element to see if it supports an attribute named name.

Since parseDTD no longer works, this function isn't expected to work either and will be removed in a future version of XML.

Usage

dtdIsAttribute(name, element, dtd)

Arguments

name

The name of the attribute being queried

element

The name of the element whose definition is to be used to obtain the list of valid attributes.

dtd

The DTD containing the definition of the elements, specifically element.

Value

A logical value indicating if the list of attributes suppported by the specified element has an entry named name. This does indicate what type of value that attribute has, whether it is required, implied, fixed, etc.

Author(s)

Duncan Temple Lang

References

https://www.w3.org/XML/, http://www.jclark.com/xml/, https://www.omegahat.net

See Also

parseDTD, dtdElement, xmlAttrs

Examples

 dtdFile <- system.file("exampleData", "foo.dtd", package="XML")
 foo.dtd <- parseDTD(dtdFile)

    # true
  dtdIsAttribute("numRecords", "dataset", foo.dtd)

    # false
  dtdIsAttribute("date", "dataset", foo.dtd)

XML documentation built on March 20, 2026, 9:06 a.m.

Related to dtdIsAttribute in XML...