libxmlVersion: Query the version and available features of the libxml library.
Description
libxmlVersion retrieves the version of the libxml
library used when installing this XML package.
libxmlFeatures returns a named logical vector
indicating which features are enabled.
Usage
libxmlVersion(runTime = FALSE)
libxmlFeatures()
Arguments
runTime
a logical value indicating whether to retrieve the version information
describing libxml when the R package was compiled or the run-time version.
These may be different if a) a new version of libxml2 is installed after the package is installed,
b)
Value
libxmlVersion returns a named list with
fields
majorthe major version number, either 1 or 2
indicating the old or new-style library.