xmlSize: The number of sub-elements within an XML node.

xmlSizeR Documentation

The number of sub-elements within an XML node.

Description

XML elements can contain other, nested sub-elements. This generic function determines the number of such elements within a specified node. It applies to an object of class XMLNode or XMLDocument.

Usage

xmlSize(obj)
## Default S3 method:
xmlSize(obj)

Arguments

obj

An an object of class XMLNode or XMLDocument.

Value

an integer which is the length of the value from xmlChildren.

Author(s)

Duncan Temple Lang

References

https://www.w3.org/XML/, http://www.jclark.com/xml/

See Also

xmlChildren, xmlAttrs, xmlName, xmlTreeParse

Examples

  fileName <- system.file("exampleData", "mtcars.xml", package="XML") 
  doc <- xmlTreeParse(fileName)
  xmlSize(doc)
  xmlSize(doc$doc$children[["dataset"]][["variables"]])

XML documentation built on Sept. 28, 2026, 1:07 a.m.

Related to xmlSize in XML...