| dtdElementValidEntry | R Documentation |
This tests whether name is a legitimate tag to use as a
direct sub-element of the element tag according to the
definition of the element element in the specified DTD. This
is a generic function that dispatches on the element type, so that
different version take effect for XMLSequenceContent,
XMLOrContent, XMLElementContent.
Since parseDTD no longer works, this function isn't
expected to work either and will be removed in a future version of
XML.
dtdElementValidEntry(element, name, pos=NULL)
element |
The |
name |
The name of the sub-element about which we are
querying the list of sub-tags within |
pos |
An optional argument which, if supplied,
queries whether the |
This is not intended to be called directly, but
indirectly by the
dtdValidElement function.
Logical value indicating whether the sub-element
can appear in an element tag or not.
Duncan Temple Lang
https://www.w3.org/XML/, http://www.jclark.com/xml/, https://www.omegahat.net
parseDTD,
dtdValidElement,
dtdElement
dtdFile <- system.file("exampleData", "foo.dtd",package="XML")
dtd <- parseDTD(dtdFile)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.